@@ -1,12 +1,11 @@
 from dataclasses import dataclass
-from io import StringIO
 
 from jubeatools.song import Chart, Song
 
 
 @dataclass
 class JubeatFile:
-    contents: StringIO
+    contents: bytes
 
 
 @dataclass
