@@ -102,7 +102,7 @@ memo2_chart_line_grammar = Grammar(
     bpm             = "(" float ")"
     float           = ~r"\d+(\.\d+)?"
     notes           = ~r"[^*#:\(\[|/\s]+"
-    ws              = ~r"[\t ]*"
+    ws              = ~r"[\t \u3000]*" # U+03000 : IDEOGRAPHIC SPACE
     comment         = ~r"//.*"
 """
 )
@@ -180,20 +180,16 @@ class Memo2Parser(JubeatAnalyserParser):
         self.frames: List[Memo2Frame] = []
 
     def do_b(self, value: str) -> None:
-        raise RuntimeError(
-            "beat command (b=...) found, this commands cannot be used in #memo2 files"
-        )
+        if Decimal(value) != 4:
+            raise RuntimeError(
+                "Beat command (b=...) found with a value other that 4, this is "
+                "unexpected in #memo2 files. If you are sure the file is not "
+                "just actually a #memo1 or #memo file with the wrong format "
+                "tag, you're welcome to report this error as a bug"
+            )
 
     def do_t(self, value: str) -> None:
-        if self.frames:
-            raise RuntimeError(
-                "tempo command (t=...) found outside of the file header, "
-                "this should not happen in #memo2 files"
-            )
-        else:
-            self.timing_events.append(
-                BPMEvent(self._current_beat(), BPM=Decimal(value))
-            )
+        self.timing_events.append(BPMEvent(self._current_beat(), BPM=Decimal(value)))
 
     def do_r(self, value: str) -> None:
         if self.frames:
@@ -217,14 +213,18 @@ class Memo2Parser(JubeatAnalyserParser):
             self._do_bpp(value)
 
     def append_chart_line(self, raw_line: RawMemo2ChartLine) -> None:
-        if len(raw_line.position.encode("shift-jis-2004")) != 4 * self.bytes_per_panel:
+        if (
+            len(raw_line.position.encode("shift-jis-2004", errors="surrogateescape"))
+            != 4 * self.bytes_per_panel
+        ):
             raise SyntaxError(
                 f"Invalid chart line for #bpp={self.bytes_per_panel} : {raw_line}"
             )
 
         if raw_line.timing is not None and self.bytes_per_panel == 2:
             if any(
-                len(e.string.encode("shift-jis-2004")) % 2 != 0
+                len(e.string.encode("shift-jis-2004", errors="surrogateescape")) % 2
+                != 0
                 for e in raw_line.timing
                 if isinstance(e, NoteCluster)
             ):
